@@ -1,10 +1,10 @@
 package Term::HiliteDiff;
 
 use strict;
-use vars qw( $VERSION @EXPORT_OK %EXPORT_TAGS );
+use vars qw( $VERSION @EXPORT_OK %EXPORT_TAGS $DEFAULTOBJ );
 use Term::HiliteDiff::_impl ();
 
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 use Exporter ();
 *import      = \&Exporter::import;
@@ -20,7 +20,7 @@ if ( $0 eq '-e' ) {
 
 # Here are some convenience functions for pretending this module isn't
 # object oriented.
-my $DEFAULTOBJ = __PACKAGE__->new;
+$DEFAULTOBJ = __PACKAGE__->new;
 
 sub hilite_diff {
     return $DEFAULTOBJ->hilite_diff(@_);
@@ -32,10 +32,11 @@ sub watch {
 
 # Hey, a class constructor.
 sub new {
-    my $class = shift @_;
+    my ( $class ) = @_;
 
     return bless [], "${class}::_impl";
 }
 
-# This quote is blatantly copied from Michael Poe of errantstory.com.
-q[What's the point of dreaming I'm a girl if I don't get a cool lesbian scene?!]
+# Blatantly copied this from errantstory.com
+q[What's the point of dreaming I'm a girl if I don't get a cool lesbian scene?!];
+
